%global commit 3f827ffd0f33f03e3bf3bae49e907f5cf45c1c92
%global shortcommit %(c=%{commit}; echo ${c:0:7})

Name:           lepton-eda
%global name_uc Lepton EDA
Version:        1.9.18
Release:        4%{?dist}
Summary:        Lepton Electronic Design Automation

License: GPL-2.0-or-later AND MIT AND LGPL-2.1-only AND X11
URL:     https://github.com/%{name}/%{name}
# Source0: https://github.com/%%{name}/%%{name}/releases/download/%%{version}-20220529/%%{name}-%%{version}.tar.gz
Source0: https://github.com/%{name}/%{name}/tarball/%{shortcommit}

BuildRequires: gcc guile22-devel gettext-devel intltool
BuildRequires: groff texinfo flex libstroke-devel
BuildRequires: libtool autoconf automake
BuildRequires: help2man desktop-file-utils
BuildRequires: pkgconfig(glib-2.0) >= 2.38.0
BuildRequires: pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires: pkgconfig(gdk-pixbuf-2.0) >= 2.21.0
BuildRequires: pkgconfig(cairo)
BuildRequires: pkgconfig(pango) >= 1.23.0
BuildRequires: pkgconfig(shared-mime-info)

Requires: guile22 shared-mime-info hicolor-icon-theme

%description
%{name_uc} is a suite of free software tools for designing
electronics. It provides schematic capture, netlisting into
over 30 netlist formats, and many other features. It was
forked from the gEDA/gaf suite in late 2016 by most of its
active developers at that time. %{name_uc} is backward
compatible with its predecessor and supports the same file
format for symbols and schematics. It's in active development
and well supported.

%package doc
Summary: Documentation files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
BuildArch:      noarch

%description doc
Documentation files for %{name}

%package devel
Summary: Development files for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development files for %{name}

%prep

%setup -n %{name}-%{name}-%{shortcommit}

# update FSF address... damn, those guys move around a lot
# ... anyways, better make sure they get their mail
%global oa1 675 Mass Ave, Cambridge, MA 02139, USA
%global oa2 59 Temple Place, Suite 330, Boston, MA\\s+02111(\\-1307)?\\s+USA
%global an  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
%global re_oa %{oa1}|%{oa2}

set +x
echo "Updating FSF address:"
for f in `find . -type f -regextype posix-extended -regex '.*\.(c|cc|h|hh|scm|py|pl|inx|tcl|txt)$'`; do
    if grep -zqP "%{re_oa}" $f; then
        perl -0777 -i -pe 's/%{re_oa}/%{an}/g' $f
        echo "$f"
    fi
done
set -x

%build
./autogen.sh
%configure \
    --disable-attrib \
    --disable-rpath \
    --enable-guild \
    --with-gtk3
#    --disable-update-xdg-database \

cat <<EOF > version.h
/* Date part of package version string. */
#define PACKAGE_DATE_VERSION "20220529"

/* Dotted part of package version string. */
#define PACKAGE_DOTTED_VERSION "%{version}"

/* Current git commit. */
#define PACKAGE_GIT_COMMIT "%{commit}"
EOF

#sed -i -e 's| -shared | -Wl,--as-needed\0|g' libtool
%make_build

%install
%make_install

# a few executables without man pages
for man in lepton-{config,export,shell}; do
    help2man --no-discard-stderr "%{buildroot}%{_bindir}/$man" \
             --version-option=version \
             --output=%{buildroot}%{_mandir}/man1/$man.1
done

# install desktop files
desktop-file-install --dir %{buildroot}%{_datadir}/applications \
                       libleptongui/data/lepton-schematic.desktop
# static libraries
find %{buildroot} -type f -name '*.la' -delete -print
rm -rf %{buildroot}%{_infodir}/dir

# move binaries libs out of share
mkdir -p %{buildroot}%{_libdir}/%{name}/ccache
mv %{buildroot}%{_datadir}/%{name}/ccache/* %{buildroot}%{_libdir}/%{name}/ccache

%check

%find_lang liblepton
%find_lang libleptongui
%find_lang lepton-cli


%files -f liblepton.lang -f libleptongui.lang -f lepton-cli.lang
%license COPYING COPYING.LGPL
%doc AUTHORS
%{_bindir}/*
%{_libdir}/liblepton{,gui}.so.*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/{??x??,scalable}/mimetypes/application-x-lepton*
%{_datadir}/icons/hicolor/{48x48,scalable}/apps/lepton-schematic.*
%{_datadir}/applications/*.desktop
%{_datadir}/applications/mimeinfo.cache
%{_datadir}/mime/packages/liblepton.xml
%{_datadir}/mime/application/x-lepton-*.xml
%{_datadir}/mime/XMLnamespaces
%{_datadir}/mime/aliases
%{_datadir}/mime/generic-icons
%{_datadir}/mime/globs
%{_datadir}/mime/globs2
%{_datadir}/mime/icons
%{_datadir}/mime/magic
%{_datadir}/mime/mime.cache
%{_datadir}/mime/subclasses
%{_datadir}/mime/treemagic
%{_datadir}/mime/types
%{_datadir}/mime/version


%{_mandir}/man1/*
%{_infodir}/*

%files devel
%doc CONTRIBUTING.md
%{_includedir}/liblepton
#/usr/bin/lepton-config
%{_libdir}/liblepton{,gui}.so
%{_libdir}/pkgconfig/liblepton{,gui}.pc

%files doc
%exclude %{_docdir}/%{name}/README.md
%license %{_docdir}/%{name}/README.md
%{_docdir}/%{name}


%changelog
* Mon Sep 09 2024 Pappy <skrochen@krotek.com> 1.9.18-4
- Update to master, get ready for 1.9.19

* Sat May 04 2024 Pappy <skrochen@krotek.com> 1.9.18-3
- Build for Fedora 40

* Thu Oct 26 2023 Pappy <skrochen@krotek.com> 1.9.18-2
- Build for s-kro Copr

* Mon Aug 22 2022 dmn <graahnul.grom@gmail.com> 1.9.18-1
- Update to release 1.9.18
* Wed Dec 29 2021 dmn <graahnul.grom@gmail.com> 1.9.17-1
- Update to release 1.9.17
* Thu Sep 09 2021 dmn <graahnul.grom@gmail.com> 1.9.16-1
- Update to release 1.9.16
* Sun Jun 27 2021 dmn <graahnul.grom@gmail.com> 1.9.15-1
- Update to release 1.9.15
* Mon Apr 12 2021 dmn <graahnul.grom@gmail.com> 1.9.14-1
- Update to release 1.9.14
* Mon Dec 14 2020 dmn <graahnul.grom@gmail.com> 1.9.13-1
- Update to release 1.9.13
* Fri Jun 05 2020 dmn <graahnul.grom@gmail.com> 1.9.11-1
- Update to release 1.9.11
* Fri May 15 2020 dmn <graahnul.grom@gmail.com> 1.9.10-1
- Initial version of the package
